declare const _default: {
    /**
     * Lookup3: frame_system::AccountInfo<Index, pallet_balances::AccountData<Balance>>
     */
    FrameSystemAccountInfo: {
        nonce: string;
        consumers: string;
        providers: string;
        sufficients: string;
        data: string;
    };
    /**
     * Lookup5: pallet_balances::AccountData<Balance>
     */
    PalletBalancesAccountData: {
        free: string;
        reserved: string;
        miscFrozen: string;
        feeFrozen: string;
    };
    /**
     * Lookup7: frame_support::weights::PerDispatchClass<T>
     */
    FrameSupportWeightsPerDispatchClassU64: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup12: sp_runtime::generic::digest::Digest
     */
    SpRuntimeDigest: {
        logs: string;
    };
    /**
     * Lookup14: sp_runtime::generic::digest::DigestItem
     */
    SpRuntimeDigestDigestItem: {
        _enum: {
            Other: string;
            __Unused1: string;
            __Unused2: string;
            __Unused3: string;
            Consensus: string;
            Seal: string;
            PreRuntime: string;
            __Unused7: string;
            RuntimeEnvironmentUpdated: string;
        };
    };
    /**
     * Lookup17: frame_system::EventRecord<moonbase_runtime::Event, primitive_types::H256>
     */
    FrameSystemEventRecord: {
        phase: string;
        event: string;
        topics: string;
    };
    /**
     * Lookup19: frame_system::pallet::Event<T>
     */
    FrameSystemEvent: {
        _enum: {
            ExtrinsicSuccess: {
                dispatchInfo: string;
            };
            ExtrinsicFailed: {
                dispatchError: string;
                dispatchInfo: string;
            };
            CodeUpdated: string;
            NewAccount: {
                account: string;
            };
            KilledAccount: {
                account: string;
            };
            Remarked: {
                _alias: {
                    hash_: string;
                };
                sender: string;
                hash_: string;
            };
        };
    };
    /**
     * Lookup20: frame_support::weights::DispatchInfo
     */
    FrameSupportWeightsDispatchInfo: {
        weight: string;
        class: string;
        paysFee: string;
    };
    /**
     * Lookup21: frame_support::weights::DispatchClass
     */
    FrameSupportWeightsDispatchClass: {
        _enum: string[];
    };
    /**
     * Lookup22: frame_support::weights::Pays
     */
    FrameSupportWeightsPays: {
        _enum: string[];
    };
    /**
     * Lookup23: sp_runtime::DispatchError
     */
    SpRuntimeDispatchError: {
        _enum: {
            Other: string;
            CannotLookup: string;
            BadOrigin: string;
            Module: string;
            ConsumerRemaining: string;
            NoProviders: string;
            TooManyConsumers: string;
            Token: string;
            Arithmetic: string;
            Transactional: string;
        };
    };
    /**
     * Lookup24: sp_runtime::ModuleError
     */
    SpRuntimeModuleError: {
        index: string;
        error: string;
    };
    /**
     * Lookup25: sp_runtime::TokenError
     */
    SpRuntimeTokenError: {
        _enum: string[];
    };
    /**
     * Lookup26: sp_runtime::ArithmeticError
     */
    SpRuntimeArithmeticError: {
        _enum: string[];
    };
    /**
     * Lookup27: sp_runtime::TransactionalError
     */
    SpRuntimeTransactionalError: {
        _enum: string[];
    };
    /**
     * Lookup28: pallet_utility::pallet::Event
     */
    PalletUtilityEvent: {
        _enum: {
            BatchInterrupted: {
                index: string;
                error: string;
            };
            BatchCompleted: string;
            ItemCompleted: string;
            DispatchedAs: {
                result: string;
            };
        };
    };
    /**
     * Lookup31: pallet_balances::pallet::Event<T, I>
     */
    PalletBalancesEvent: {
        _enum: {
            Endowed: {
                account: string;
                freeBalance: string;
            };
            DustLost: {
                account: string;
                amount: string;
            };
            Transfer: {
                from: string;
                to: string;
                amount: string;
            };
            BalanceSet: {
                who: string;
                free: string;
                reserved: string;
            };
            Reserved: {
                who: string;
                amount: string;
            };
            Unreserved: {
                who: string;
                amount: string;
            };
            ReserveRepatriated: {
                from: string;
                to: string;
                amount: string;
                destinationStatus: string;
            };
            Deposit: {
                who: string;
                amount: string;
            };
            Withdraw: {
                who: string;
                amount: string;
            };
            Slashed: {
                who: string;
                amount: string;
            };
        };
    };
    /**
     * Lookup32: frame_support::traits::tokens::misc::BalanceStatus
     */
    FrameSupportTokensMiscBalanceStatus: {
        _enum: string[];
    };
    /**
     * Lookup33: pallet_sudo::pallet::Event<T>
     */
    PalletSudoEvent: {
        _enum: {
            Sudid: {
                sudoResult: string;
            };
            KeyChanged: {
                oldSudoer: string;
            };
            SudoAsDone: {
                sudoResult: string;
            };
        };
    };
    /**
     * Lookup35: cumulus_pallet_parachain_system::pallet::Event<T>
     */
    CumulusPalletParachainSystemEvent: {
        _enum: {
            ValidationFunctionStored: string;
            ValidationFunctionApplied: string;
            ValidationFunctionDiscarded: string;
            UpgradeAuthorized: string;
            DownwardMessagesReceived: string;
            DownwardMessagesProcessed: string;
        };
    };
    /**
     * Lookup36: pallet_evm::pallet::Event<T>
     */
    PalletEvmEvent: {
        _enum: {
            Log: string;
            Created: string;
            CreatedFailed: string;
            Executed: string;
            ExecutedFailed: string;
            BalanceDeposit: string;
            BalanceWithdraw: string;
        };
    };
    /**
     * Lookup37: ethereum::log::Log
     */
    EthereumLog: {
        address: string;
        topics: string;
        data: string;
    };
    /**
     * Lookup42: pallet_ethereum::pallet::Event
     */
    PalletEthereumEvent: {
        _enum: {
            Executed: string;
        };
    };
    /**
     * Lookup43: evm_core::error::ExitReason
     */
    EvmCoreErrorExitReason: {
        _enum: {
            Succeed: string;
            Error: string;
            Revert: string;
            Fatal: string;
        };
    };
    /**
     * Lookup44: evm_core::error::ExitSucceed
     */
    EvmCoreErrorExitSucceed: {
        _enum: string[];
    };
    /**
     * Lookup45: evm_core::error::ExitError
     */
    EvmCoreErrorExitError: {
        _enum: {
            StackUnderflow: string;
            StackOverflow: string;
            InvalidJump: string;
            InvalidRange: string;
            DesignatedInvalid: string;
            CallTooDeep: string;
            CreateCollision: string;
            CreateContractLimit: string;
            OutOfOffset: string;
            OutOfGas: string;
            OutOfFund: string;
            PCUnderflow: string;
            CreateEmpty: string;
            Other: string;
            InvalidCode: string;
        };
    };
    /**
     * Lookup48: evm_core::error::ExitRevert
     */
    EvmCoreErrorExitRevert: {
        _enum: string[];
    };
    /**
     * Lookup49: evm_core::error::ExitFatal
     */
    EvmCoreErrorExitFatal: {
        _enum: {
            NotSupported: string;
            UnhandledInterrupt: string;
            CallErrorAsFatal: string;
            Other: string;
        };
    };
    /**
     * Lookup50: parachain_staking::pallet::Event<T>
     */
    ParachainStakingEvent: {
        _enum: {
            NewRound: {
                startingBlock: string;
                round: string;
                selectedCollatorsNumber: string;
                totalBalance: string;
            };
            JoinedCollatorCandidates: {
                account: string;
                amountLocked: string;
                newTotalAmtLocked: string;
            };
            CollatorChosen: {
                round: string;
                collatorAccount: string;
                totalExposedAmount: string;
            };
            CandidateBondLessRequested: {
                candidate: string;
                amountToDecrease: string;
                executeRound: string;
            };
            CandidateBondedMore: {
                candidate: string;
                amount: string;
                newTotalBond: string;
            };
            CandidateBondedLess: {
                candidate: string;
                amount: string;
                newBond: string;
            };
            CandidateWentOffline: {
                candidate: string;
            };
            CandidateBackOnline: {
                candidate: string;
            };
            CandidateScheduledExit: {
                exitAllowedRound: string;
                candidate: string;
                scheduledExit: string;
            };
            CancelledCandidateExit: {
                candidate: string;
            };
            CancelledCandidateBondLess: {
                candidate: string;
                amount: string;
                executeRound: string;
            };
            CandidateLeft: {
                exCandidate: string;
                unlockedAmount: string;
                newTotalAmtLocked: string;
            };
            DelegationDecreaseScheduled: {
                delegator: string;
                candidate: string;
                amountToDecrease: string;
                executeRound: string;
            };
            DelegationIncreased: {
                delegator: string;
                candidate: string;
                amount: string;
                inTop: string;
            };
            DelegationDecreased: {
                delegator: string;
                candidate: string;
                amount: string;
                inTop: string;
            };
            DelegatorExitScheduled: {
                round: string;
                delegator: string;
                scheduledExit: string;
            };
            DelegationRevocationScheduled: {
                round: string;
                delegator: string;
                candidate: string;
                scheduledExit: string;
            };
            DelegatorLeft: {
                delegator: string;
                unstakedAmount: string;
            };
            DelegationRevoked: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
            };
            DelegationKicked: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
            };
            DelegatorExitCancelled: {
                delegator: string;
            };
            CancelledDelegationRequest: {
                delegator: string;
                cancelledRequest: string;
                collator: string;
            };
            Delegation: {
                delegator: string;
                lockedAmount: string;
                candidate: string;
                delegatorPosition: string;
            };
            DelegatorLeftCandidate: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
                totalCandidateStaked: string;
            };
            Rewarded: {
                account: string;
                rewards: string;
            };
            ReservedForParachainBond: {
                account: string;
                value: string;
            };
            ParachainBondAccountSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            ParachainBondReservePercentSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            InflationSet: {
                annualMin: string;
                annualIdeal: string;
                annualMax: string;
                roundMin: string;
                roundIdeal: string;
                roundMax: string;
            };
            StakeExpectationsSet: {
                expectMin: string;
                expectIdeal: string;
                expectMax: string;
            };
            TotalSelectedSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            CollatorCommissionSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            BlocksPerRoundSet: {
                _alias: {
                    new_: string;
                };
                currentRound: string;
                firstBlock: string;
                old: string;
                new_: string;
                newPerRoundInflationMin: string;
                newPerRoundInflationIdeal: string;
                newPerRoundInflationMax: string;
            };
        };
    };
    /**
     * Lookup52: parachain_staking::delegation_requests::CancelledScheduledRequest<Balance>
     */
    ParachainStakingDelegationRequestsCancelledScheduledRequest: {
        whenExecutable: string;
        action: string;
    };
    /**
     * Lookup53: parachain_staking::delegation_requests::DelegationAction<Balance>
     */
    ParachainStakingDelegationRequestsDelegationAction: {
        _enum: {
            Revoke: string;
            Decrease: string;
        };
    };
    /**
     * Lookup54: parachain_staking::types::DelegatorAdded<B>
     */
    ParachainStakingDelegatorAdded: {
        _enum: {
            AddedToTop: {
                newTotal: string;
            };
            AddedToBottom: string;
        };
    };
    /**
     * Lookup57: pallet_scheduler::pallet::Event<T>
     */
    PalletSchedulerEvent: {
        _enum: {
            Scheduled: {
                when: string;
                index: string;
            };
            Canceled: {
                when: string;
                index: string;
            };
            Dispatched: {
                task: string;
                id: string;
                result: string;
            };
            CallLookupFailed: {
                task: string;
                id: string;
                error: string;
            };
        };
    };
    /**
     * Lookup60: frame_support::traits::schedule::LookupError
     */
    FrameSupportScheduleLookupError: {
        _enum: string[];
    };
    /**
     * Lookup61: pallet_democracy::pallet::Event<T>
     */
    PalletDemocracyEvent: {
        _enum: {
            Proposed: {
                proposalIndex: string;
                deposit: string;
            };
            Tabled: {
                proposalIndex: string;
                deposit: string;
                depositors: string;
            };
            ExternalTabled: string;
            Started: {
                refIndex: string;
                threshold: string;
            };
            Passed: {
                refIndex: string;
            };
            NotPassed: {
                refIndex: string;
            };
            Cancelled: {
                refIndex: string;
            };
            Executed: {
                refIndex: string;
                result: string;
            };
            Delegated: {
                who: string;
                target: string;
            };
            Undelegated: {
                account: string;
            };
            Vetoed: {
                who: string;
                proposalHash: string;
                until: string;
            };
            PreimageNoted: {
                proposalHash: string;
                who: string;
                deposit: string;
            };
            PreimageUsed: {
                proposalHash: string;
                provider: string;
                deposit: string;
            };
            PreimageInvalid: {
                proposalHash: string;
                refIndex: string;
            };
            PreimageMissing: {
                proposalHash: string;
                refIndex: string;
            };
            PreimageReaped: {
                proposalHash: string;
                provider: string;
                deposit: string;
                reaper: string;
            };
            Blacklisted: {
                proposalHash: string;
            };
            Voted: {
                voter: string;
                refIndex: string;
                vote: string;
            };
            Seconded: {
                seconder: string;
                propIndex: string;
            };
        };
    };
    /**
     * Lookup63: pallet_democracy::vote_threshold::VoteThreshold
     */
    PalletDemocracyVoteThreshold: {
        _enum: string[];
    };
    /**
     * Lookup64: pallet_democracy::vote::AccountVote<Balance>
     */
    PalletDemocracyVoteAccountVote: {
        _enum: {
            Standard: {
                vote: string;
                balance: string;
            };
            Split: {
                aye: string;
                nay: string;
            };
        };
    };
    /**
     * Lookup66: pallet_collective::pallet::Event<T, I>
     */
    PalletCollectiveEvent: {
        _enum: {
            Proposed: {
                account: string;
                proposalIndex: string;
                proposalHash: string;
                threshold: string;
            };
            Voted: {
                account: string;
                proposalHash: string;
                voted: string;
                yes: string;
                no: string;
            };
            Approved: {
                proposalHash: string;
            };
            Disapproved: {
                proposalHash: string;
            };
            Executed: {
                proposalHash: string;
                result: string;
            };
            MemberExecuted: {
                proposalHash: string;
                result: string;
            };
            Closed: {
                proposalHash: string;
                yes: string;
                no: string;
            };
        };
    };
    /**
     * Lookup68: pallet_treasury::pallet::Event<T, I>
     */
    PalletTreasuryEvent: {
        _enum: {
            Proposed: {
                proposalIndex: string;
            };
            Spending: {
                budgetRemaining: string;
            };
            Awarded: {
                proposalIndex: string;
                award: string;
                account: string;
            };
            Rejected: {
                proposalIndex: string;
                slashed: string;
            };
            Burnt: {
                burntFunds: string;
            };
            Rollover: {
                rolloverBalance: string;
            };
            Deposit: {
                value: string;
            };
        };
    };
    /**
     * Lookup69: pallet_author_slot_filter::pallet::Event
     */
    PalletAuthorSlotFilterEvent: {
        _enum: {
            EligibleUpdated: string;
        };
    };
    /**
     * Lookup71: pallet_crowdloan_rewards::pallet::Event<T>
     */
    PalletCrowdloanRewardsEvent: {
        _enum: {
            InitialPaymentMade: string;
            NativeIdentityAssociated: string;
            RewardsPaid: string;
            RewardAddressUpdated: string;
            InitializedAlreadyInitializedAccount: string;
            InitializedAccountWithNotEnoughContribution: string;
        };
    };
    /**
     * Lookup72: pallet_author_mapping::pallet::Event<T>
     */
    PalletAuthorMappingEvent: {
        _enum: {
            KeysRegistered: {
                _alias: {
                    keys_: string;
                };
                nimbusId: string;
                accountId: string;
                keys_: string;
            };
            KeysRemoved: {
                _alias: {
                    keys_: string;
                };
                nimbusId: string;
                accountId: string;
                keys_: string;
            };
            KeysRotated: {
                newNimbusId: string;
                accountId: string;
                newKeys: string;
            };
        };
    };
    /**
     * Lookup73: nimbus_primitives::nimbus_crypto::Public
     */
    NimbusPrimitivesNimbusCryptoPublic: string;
    /**
     * Lookup74: sp_core::sr25519::Public
     */
    SpCoreSr25519Public: string;
    /**
     * Lookup75: session_keys_primitives::vrf::vrf_crypto::Public
     */
    SessionKeysPrimitivesVrfVrfCryptoPublic: string;
    /**
     * Lookup76: pallet_proxy::pallet::Event<T>
     */
    PalletProxyEvent: {
        _enum: {
            ProxyExecuted: {
                result: string;
            };
            AnonymousCreated: {
                anonymous: string;
                who: string;
                proxyType: string;
                disambiguationIndex: string;
            };
            Announced: {
                real: string;
                proxy: string;
                callHash: string;
            };
            ProxyAdded: {
                delegator: string;
                delegatee: string;
                proxyType: string;
                delay: string;
            };
            ProxyRemoved: {
                delegator: string;
                delegatee: string;
                proxyType: string;
                delay: string;
            };
        };
    };
    /**
     * Lookup77: moonbase_runtime::ProxyType
     */
    MoonbaseRuntimeProxyType: {
        _enum: string[];
    };
    /**
     * Lookup79: pallet_maintenance_mode::pallet::Event
     */
    PalletMaintenanceModeEvent: {
        _enum: {
            EnteredMaintenanceMode: string;
            NormalOperationResumed: string;
            FailedToSuspendIdleXcmExecution: {
                error: string;
            };
            FailedToResumeIdleXcmExecution: {
                error: string;
            };
        };
    };
    /**
     * Lookup80: pallet_identity::pallet::Event<T>
     */
    PalletIdentityEvent: {
        _enum: {
            IdentitySet: {
                who: string;
            };
            IdentityCleared: {
                who: string;
                deposit: string;
            };
            IdentityKilled: {
                who: string;
                deposit: string;
            };
            JudgementRequested: {
                who: string;
                registrarIndex: string;
            };
            JudgementUnrequested: {
                who: string;
                registrarIndex: string;
            };
            JudgementGiven: {
                target: string;
                registrarIndex: string;
            };
            RegistrarAdded: {
                registrarIndex: string;
            };
            SubIdentityAdded: {
                sub: string;
                main: string;
                deposit: string;
            };
            SubIdentityRemoved: {
                sub: string;
                main: string;
                deposit: string;
            };
            SubIdentityRevoked: {
                sub: string;
                main: string;
                deposit: string;
            };
        };
    };
    /**
     * Lookup81: cumulus_pallet_xcmp_queue::pallet::Event<T>
     */
    CumulusPalletXcmpQueueEvent: {
        _enum: {
            Success: string;
            Fail: string;
            BadVersion: string;
            BadFormat: string;
            UpwardMessageSent: string;
            XcmpMessageSent: string;
            OverweightEnqueued: string;
            OverweightServiced: string;
        };
    };
    /**
     * Lookup83: xcm::v2::traits::Error
     */
    XcmV2TraitsError: {
        _enum: {
            Overflow: string;
            Unimplemented: string;
            UntrustedReserveLocation: string;
            UntrustedTeleportLocation: string;
            MultiLocationFull: string;
            MultiLocationNotInvertible: string;
            BadOrigin: string;
            InvalidLocation: string;
            AssetNotFound: string;
            FailedToTransactAsset: string;
            NotWithdrawable: string;
            LocationCannotHold: string;
            ExceedsMaxMessageSize: string;
            DestinationUnsupported: string;
            Transport: string;
            Unroutable: string;
            UnknownClaim: string;
            FailedToDecode: string;
            MaxWeightInvalid: string;
            NotHoldingFees: string;
            TooExpensive: string;
            Trap: string;
            UnhandledXcmVersion: string;
            WeightLimitReached: string;
            Barrier: string;
            WeightNotComputable: string;
        };
    };
    /**
     * Lookup85: cumulus_pallet_xcm::pallet::Event<T>
     */
    CumulusPalletXcmEvent: {
        _enum: {
            InvalidFormat: string;
            UnsupportedVersion: string;
            ExecutedDownward: string;
        };
    };
    /**
     * Lookup87: xcm::v2::traits::Outcome
     */
    XcmV2TraitsOutcome: {
        _enum: {
            Complete: string;
            Incomplete: string;
            Error: string;
        };
    };
    /**
     * Lookup88: cumulus_pallet_dmp_queue::pallet::Event<T>
     */
    CumulusPalletDmpQueueEvent: {
        _enum: {
            InvalidFormat: string;
            UnsupportedVersion: string;
            ExecutedDownward: string;
            WeightExhausted: string;
            OverweightEnqueued: string;
            OverweightServiced: string;
        };
    };
    /**
     * Lookup89: pallet_xcm::pallet::Event<T>
     */
    PalletXcmEvent: {
        _enum: {
            Attempted: string;
            Sent: string;
            UnexpectedResponse: string;
            ResponseReady: string;
            Notified: string;
            NotifyOverweight: string;
            NotifyDispatchError: string;
            NotifyDecodeFailed: string;
            InvalidResponder: string;
            InvalidResponderVersion: string;
            ResponseTaken: string;
            AssetsTrapped: string;
            VersionChangeNotified: string;
            SupportedVersionChanged: string;
            NotifyTargetSendFail: string;
            NotifyTargetMigrationFail: string;
        };
    };
    /**
     * Lookup90: xcm::v1::multilocation::MultiLocation
     */
    XcmV1MultiLocation: {
        parents: string;
        interior: string;
    };
    /**
     * Lookup91: xcm::v1::multilocation::Junctions
     */
    XcmV1MultilocationJunctions: {
        _enum: {
            Here: string;
            X1: string;
            X2: string;
            X3: string;
            X4: string;
            X5: string;
            X6: string;
            X7: string;
            X8: string;
        };
    };
    /**
     * Lookup92: xcm::v1::junction::Junction
     */
    XcmV1Junction: {
        _enum: {
            Parachain: string;
            AccountId32: {
                network: string;
                id: string;
            };
            AccountIndex64: {
                network: string;
                index: string;
            };
            AccountKey20: {
                network: string;
                key: string;
            };
            PalletInstance: string;
            GeneralIndex: string;
            GeneralKey: string;
            OnlyChild: string;
            Plurality: {
                id: string;
                part: string;
            };
        };
    };
    /**
     * Lookup94: xcm::v0::junction::NetworkId
     */
    XcmV0JunctionNetworkId: {
        _enum: {
            Any: string;
            Named: string;
            Polkadot: string;
            Kusama: string;
        };
    };
    /**
     * Lookup97: xcm::v0::junction::BodyId
     */
    XcmV0JunctionBodyId: {
        _enum: {
            Unit: string;
            Named: string;
            Index: string;
            Executive: string;
            Technical: string;
            Legislative: string;
            Judicial: string;
        };
    };
    /**
     * Lookup98: xcm::v0::junction::BodyPart
     */
    XcmV0JunctionBodyPart: {
        _enum: {
            Voice: string;
            Members: {
                count: string;
            };
            Fraction: {
                nom: string;
                denom: string;
            };
            AtLeastProportion: {
                nom: string;
                denom: string;
            };
            MoreThanProportion: {
                nom: string;
                denom: string;
            };
        };
    };
    /**
     * Lookup99: xcm::v2::Xcm<Call>
     */
    XcmV2Xcm: string;
    /**
     * Lookup101: xcm::v2::Instruction<Call>
     */
    XcmV2Instruction: {
        _enum: {
            WithdrawAsset: string;
            ReserveAssetDeposited: string;
            ReceiveTeleportedAsset: string;
            QueryResponse: {
                queryId: string;
                response: string;
                maxWeight: string;
            };
            TransferAsset: {
                assets: string;
                beneficiary: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                xcm: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            ClearOrigin: string;
            DescendOrigin: string;
            ReportError: {
                queryId: string;
                dest: string;
                maxResponseWeight: string;
            };
            DepositAsset: {
                assets: string;
                maxAssets: string;
                beneficiary: string;
            };
            DepositReserveAsset: {
                assets: string;
                maxAssets: string;
                dest: string;
                xcm: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                xcm: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                xcm: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
                maxResponseWeight: string;
            };
            BuyExecution: {
                fees: string;
                weightLimit: string;
            };
            RefundSurplus: string;
            SetErrorHandler: string;
            SetAppendix: string;
            ClearError: string;
            ClaimAsset: {
                assets: string;
                ticket: string;
            };
            Trap: string;
            SubscribeVersion: {
                queryId: string;
                maxResponseWeight: string;
            };
            UnsubscribeVersion: string;
        };
    };
    /**
     * Lookup102: xcm::v1::multiasset::MultiAssets
     */
    XcmV1MultiassetMultiAssets: string;
    /**
     * Lookup104: xcm::v1::multiasset::MultiAsset
     */
    XcmV1MultiAsset: {
        id: string;
        fun: string;
    };
    /**
     * Lookup105: xcm::v1::multiasset::AssetId
     */
    XcmV1MultiassetAssetId: {
        _enum: {
            Concrete: string;
            Abstract: string;
        };
    };
    /**
     * Lookup106: xcm::v1::multiasset::Fungibility
     */
    XcmV1MultiassetFungibility: {
        _enum: {
            Fungible: string;
            NonFungible: string;
        };
    };
    /**
     * Lookup107: xcm::v1::multiasset::AssetInstance
     */
    XcmV1MultiassetAssetInstance: {
        _enum: {
            Undefined: string;
            Index: string;
            Array4: string;
            Array8: string;
            Array16: string;
            Array32: string;
            Blob: string;
        };
    };
    /**
     * Lookup109: xcm::v2::Response
     */
    XcmV2Response: {
        _enum: {
            Null: string;
            Assets: string;
            ExecutionResult: string;
            Version: string;
        };
    };
    /**
     * Lookup112: xcm::v0::OriginKind
     */
    XcmV0OriginKind: {
        _enum: string[];
    };
    /**
     * Lookup113: xcm::double_encoded::DoubleEncoded<T>
     */
    XcmDoubleEncoded: {
        encoded: string;
    };
    /**
     * Lookup114: xcm::v1::multiasset::MultiAssetFilter
     */
    XcmV1MultiassetMultiAssetFilter: {
        _enum: {
            Definite: string;
            Wild: string;
        };
    };
    /**
     * Lookup115: xcm::v1::multiasset::WildMultiAsset
     */
    XcmV1MultiassetWildMultiAsset: {
        _enum: {
            All: string;
            AllOf: {
                id: string;
                fun: string;
            };
        };
    };
    /**
     * Lookup116: xcm::v1::multiasset::WildFungibility
     */
    XcmV1MultiassetWildFungibility: {
        _enum: string[];
    };
    /**
     * Lookup117: xcm::v2::WeightLimit
     */
    XcmV2WeightLimit: {
        _enum: {
            Unlimited: string;
            Limited: string;
        };
    };
    /**
     * Lookup119: xcm::VersionedMultiAssets
     */
    XcmVersionedMultiAssets: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup121: xcm::v0::multi_asset::MultiAsset
     */
    XcmV0MultiAsset: {
        _enum: {
            None: string;
            All: string;
            AllFungible: string;
            AllNonFungible: string;
            AllAbstractFungible: {
                id: string;
            };
            AllAbstractNonFungible: {
                class: string;
            };
            AllConcreteFungible: {
                id: string;
            };
            AllConcreteNonFungible: {
                class: string;
            };
            AbstractFungible: {
                id: string;
                amount: string;
            };
            AbstractNonFungible: {
                class: string;
                instance: string;
            };
            ConcreteFungible: {
                id: string;
                amount: string;
            };
            ConcreteNonFungible: {
                class: string;
                instance: string;
            };
        };
    };
    /**
     * Lookup122: xcm::v0::multi_location::MultiLocation
     */
    XcmV0MultiLocation: {
        _enum: {
            Null: string;
            X1: string;
            X2: string;
            X3: string;
            X4: string;
            X5: string;
            X6: string;
            X7: string;
            X8: string;
        };
    };
    /**
     * Lookup123: xcm::v0::junction::Junction
     */
    XcmV0Junction: {
        _enum: {
            Parent: string;
            Parachain: string;
            AccountId32: {
                network: string;
                id: string;
            };
            AccountIndex64: {
                network: string;
                index: string;
            };
            AccountKey20: {
                network: string;
                key: string;
            };
            PalletInstance: string;
            GeneralIndex: string;
            GeneralKey: string;
            OnlyChild: string;
            Plurality: {
                id: string;
                part: string;
            };
        };
    };
    /**
     * Lookup124: xcm::VersionedMultiLocation
     */
    XcmVersionedMultiLocation: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup125: pallet_assets::pallet::Event<T, I>
     */
    PalletAssetsEvent: {
        _enum: {
            Created: {
                assetId: string;
                creator: string;
                owner: string;
            };
            Issued: {
                assetId: string;
                owner: string;
                totalSupply: string;
            };
            Transferred: {
                assetId: string;
                from: string;
                to: string;
                amount: string;
            };
            Burned: {
                assetId: string;
                owner: string;
                balance: string;
            };
            TeamChanged: {
                assetId: string;
                issuer: string;
                admin: string;
                freezer: string;
            };
            OwnerChanged: {
                assetId: string;
                owner: string;
            };
            Frozen: {
                assetId: string;
                who: string;
            };
            Thawed: {
                assetId: string;
                who: string;
            };
            AssetFrozen: {
                assetId: string;
            };
            AssetThawed: {
                assetId: string;
            };
            Destroyed: {
                assetId: string;
            };
            ForceCreated: {
                assetId: string;
                owner: string;
            };
            MetadataSet: {
                assetId: string;
                name: string;
                symbol: string;
                decimals: string;
                isFrozen: string;
            };
            MetadataCleared: {
                assetId: string;
            };
            ApprovedTransfer: {
                assetId: string;
                source: string;
                delegate: string;
                amount: string;
            };
            ApprovalCancelled: {
                assetId: string;
                owner: string;
                delegate: string;
            };
            TransferredApproved: {
                assetId: string;
                owner: string;
                delegate: string;
                destination: string;
                amount: string;
            };
            AssetStatusChanged: {
                assetId: string;
            };
        };
    };
    /**
     * Lookup126: orml_xtokens::module::Event<T>
     */
    OrmlXtokensModuleEvent: {
        _enum: {
            TransferredMultiAssets: {
                sender: string;
                assets: string;
                fee: string;
                dest: string;
            };
        };
    };
    /**
     * Lookup127: pallet_asset_manager::pallet::Event<T>
     */
    PalletAssetManagerEvent: {
        _enum: {
            ForeignAssetRegistered: {
                assetId: string;
                asset: string;
                metadata: string;
            };
            UnitsPerSecondChanged: {
                assetType: string;
                unitsPerSecond: string;
            };
            ForeignAssetTypeChanged: {
                assetId: string;
                newAssetType: string;
            };
            ForeignAssetRemoved: {
                assetId: string;
                assetType: string;
            };
            SupportedAssetRemoved: {
                assetType: string;
            };
            LocalAssetRegistered: {
                assetId: string;
                creator: string;
                owner: string;
            };
            ForeignAssetDestroyed: {
                assetId: string;
                assetType: string;
            };
            LocalAssetDestroyed: {
                assetId: string;
            };
        };
    };
    /**
     * Lookup128: moonbase_runtime::xcm_config::AssetType
     */
    MoonbaseRuntimeXcmConfigAssetType: {
        _enum: {
            Xcm: string;
        };
    };
    /**
     * Lookup129: moonbase_runtime::asset_config::AssetRegistrarMetadata
     */
    MoonbaseRuntimeAssetConfigAssetRegistrarMetadata: {
        name: string;
        symbol: string;
        decimals: string;
        isFrozen: string;
    };
    /**
     * Lookup130: pallet_migrations::pallet::Event<T>
     */
    PalletMigrationsEvent: {
        _enum: {
            RuntimeUpgradeStarted: string;
            RuntimeUpgradeCompleted: {
                weight: string;
            };
            MigrationStarted: {
                migrationName: string;
            };
            MigrationCompleted: {
                migrationName: string;
                consumedWeight: string;
            };
        };
    };
    /**
     * Lookup131: xcm_transactor::pallet::Event<T>
     */
    XcmTransactorEvent: {
        _enum: {
            TransactedDerivative: {
                accountId: string;
                dest: string;
                call: string;
                index: string;
            };
            TransactedSovereign: {
                feePayer: string;
                dest: string;
                call: string;
            };
            TransactedSigned: {
                feePayer: string;
                dest: string;
                call: string;
            };
            RegisteredDerivative: {
                accountId: string;
                index: string;
            };
            DeRegisteredDerivative: {
                index: string;
            };
            TransactFailed: {
                error: string;
            };
            TransactInfoChanged: {
                location: string;
                remoteInfo: string;
            };
            TransactInfoRemoved: {
                location: string;
            };
            DestFeePerSecondChanged: {
                location: string;
                feePerSecond: string;
            };
            DestFeePerSecondRemoved: {
                location: string;
            };
        };
    };
    /**
     * Lookup132: xcm_transactor::pallet::RemoteTransactInfoWithMaxWeight
     */
    XcmTransactorRemoteTransactInfoWithMaxWeight: {
        transactExtraWeight: string;
        maxWeight: string;
        transactExtraWeightSigned: string;
    };
    /**
     * Lookup134: pallet_base_fee::pallet::Event
     */
    PalletBaseFeeEvent: {
        _enum: {
            NewBaseFeePerGas: string;
            BaseFeeOverflow: string;
            IsActive: string;
            NewElasticity: string;
        };
    };
    /**
     * Lookup137: pallet_moonbeam_orbiters::pallet::Event<T>
     */
    PalletMoonbeamOrbitersEvent: {
        _enum: {
            OrbiterJoinCollatorPool: {
                collator: string;
                orbiter: string;
            };
            OrbiterLeaveCollatorPool: {
                collator: string;
                orbiter: string;
            };
            OrbiterRewarded: {
                account: string;
                rewards: string;
            };
            OrbiterRotation: {
                collator: string;
                oldOrbiter: string;
                newOrbiter: string;
            };
            OrbiterRegistered: {
                account: string;
                deposit: string;
            };
            OrbiterUnregistered: {
                account: string;
            };
        };
    };
    /**
     * Lookup138: frame_system::Phase
     */
    FrameSystemPhase: {
        _enum: {
            ApplyExtrinsic: string;
            Finalization: string;
            Initialization: string;
        };
    };
    /**
     * Lookup140: frame_system::LastRuntimeUpgradeInfo
     */
    FrameSystemLastRuntimeUpgradeInfo: {
        specVersion: string;
        specName: string;
    };
    /**
     * Lookup141: frame_system::pallet::Call<T>
     */
    FrameSystemCall: {
        _enum: {
            fill_block: {
                ratio: string;
            };
            remark: {
                remark: string;
            };
            set_heap_pages: {
                pages: string;
            };
            set_code: {
                code: string;
            };
            set_code_without_checks: {
                code: string;
            };
            set_storage: {
                items: string;
            };
            kill_storage: {
                _alias: {
                    keys_: string;
                };
                keys_: string;
            };
            kill_prefix: {
                prefix: string;
                subkeys: string;
            };
            remark_with_event: {
                remark: string;
            };
        };
    };
    /**
     * Lookup145: frame_system::limits::BlockWeights
     */
    FrameSystemLimitsBlockWeights: {
        baseBlock: string;
        maxBlock: string;
        perClass: string;
    };
    /**
     * Lookup146:
     * frame_support::weights::PerDispatchClass<frame_system::limits::WeightsPerClass>
     */
    FrameSupportWeightsPerDispatchClassWeightsPerClass: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup147: frame_system::limits::WeightsPerClass
     */
    FrameSystemLimitsWeightsPerClass: {
        baseExtrinsic: string;
        maxExtrinsic: string;
        maxTotal: string;
        reserved: string;
    };
    /**
     * Lookup148: frame_system::limits::BlockLength
     */
    FrameSystemLimitsBlockLength: {
        max: string;
    };
    /**
     * Lookup149: frame_support::weights::PerDispatchClass<T>
     */
    FrameSupportWeightsPerDispatchClassU32: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup150: frame_support::weights::RuntimeDbWeight
     */
    FrameSupportWeightsRuntimeDbWeight: {
        read: string;
        write: string;
    };
    /**
     * Lookup151: sp_version::RuntimeVersion
     */
    SpVersionRuntimeVersion: {
        specName: string;
        implName: string;
        authoringVersion: string;
        specVersion: string;
        implVersion: string;
        apis: string;
        transactionVersion: string;
        stateVersion: string;
    };
    /**
     * Lookup155: frame_system::pallet::Error<T>
     */
    FrameSystemError: {
        _enum: string[];
    };
    /**
     * Lookup156: pallet_utility::pallet::Call<T>
     */
    PalletUtilityCall: {
        _enum: {
            batch: {
                calls: string;
            };
            as_derivative: {
                index: string;
                call: string;
            };
            batch_all: {
                calls: string;
            };
            dispatch_as: {
                asOrigin: string;
                call: string;
            };
        };
    };
    /**
     * Lookup159: pallet_timestamp::pallet::Call<T>
     */
    PalletTimestampCall: {
        _enum: {
            set: {
                now: string;
            };
        };
    };
    /**
     * Lookup160: pallet_balances::pallet::Call<T, I>
     */
    PalletBalancesCall: {
        _enum: {
            transfer: {
                dest: string;
                value: string;
            };
            set_balance: {
                who: string;
                newFree: string;
                newReserved: string;
            };
            force_transfer: {
                source: string;
                dest: string;
                value: string;
            };
            transfer_keep_alive: {
                dest: string;
                value: string;
            };
            transfer_all: {
                dest: string;
                keepAlive: string;
            };
            force_unreserve: {
                who: string;
                amount: string;
            };
        };
    };
    /**
     * Lookup161: pallet_sudo::pallet::Call<T>
     */
    PalletSudoCall: {
        _enum: {
            sudo: {
                call: string;
            };
            sudo_unchecked_weight: {
                call: string;
                weight: string;
            };
            set_key: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            sudo_as: {
                who: string;
                call: string;
            };
        };
    };
    /**
     * Lookup162: cumulus_pallet_parachain_system::pallet::Call<T>
     */
    CumulusPalletParachainSystemCall: {
        _enum: {
            set_validation_data: {
                data: string;
            };
            sudo_send_upward_message: {
                message: string;
            };
            authorize_upgrade: {
                codeHash: string;
            };
            enact_authorized_upgrade: {
                code: string;
            };
        };
    };
    /**
     * Lookup163: cumulus_primitives_parachain_inherent::ParachainInherentData
     */
    CumulusPrimitivesParachainInherentParachainInherentData: {
        validationData: string;
        relayChainState: string;
        downwardMessages: string;
        horizontalMessages: string;
    };
    /**
     * Lookup164: polkadot_primitives::v2::PersistedValidationData<primitive_types::H256, N>
     */
    PolkadotPrimitivesV2PersistedValidationData: {
        parentHead: string;
        relayParentNumber: string;
        relayParentStorageRoot: string;
        maxPovSize: string;
    };
    /**
     * Lookup166: sp_trie::storage_proof::StorageProof
     */
    SpTrieStorageProof: {
        trieNodes: string;
    };
    /**
     * Lookup169: polkadot_core_primitives::InboundDownwardMessage<BlockNumber>
     */
    PolkadotCorePrimitivesInboundDownwardMessage: {
        sentAt: string;
        msg: string;
    };
    /**
     * Lookup172: polkadot_core_primitives::InboundHrmpMessage<BlockNumber>
     */
    PolkadotCorePrimitivesInboundHrmpMessage: {
        sentAt: string;
        data: string;
    };
    /**
     * Lookup175: pallet_evm::pallet::Call<T>
     */
    PalletEvmCall: {
        _enum: {
            withdraw: {
                address: string;
                value: string;
            };
            call: {
                source: string;
                target: string;
                input: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
            create: {
                source: string;
                init: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
            create2: {
                source: string;
                init: string;
                salt: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
            hotfix_inc_account_sufficients: {
                addresses: string;
            };
        };
    };
    /**
     * Lookup180: pallet_ethereum::pallet::Call<T>
     */
    PalletEthereumCall: {
        _enum: {
            transact: {
                transaction: string;
            };
        };
    };
    /**
     * Lookup181: ethereum::transaction::TransactionV2
     */
    EthereumTransactionTransactionV2: {
        _enum: {
            Legacy: string;
            EIP2930: string;
            EIP1559: string;
        };
    };
    /**
     * Lookup182: ethereum::transaction::LegacyTransaction
     */
    EthereumTransactionLegacyTransaction: {
        nonce: string;
        gasPrice: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        signature: string;
    };
    /**
     * Lookup183: ethereum::transaction::TransactionAction
     */
    EthereumTransactionTransactionAction: {
        _enum: {
            Call: string;
            Create: string;
        };
    };
    /**
     * Lookup184: ethereum::transaction::TransactionSignature
     */
    EthereumTransactionTransactionSignature: {
        v: string;
        r: string;
        s: string;
    };
    /**
     * Lookup186: ethereum::transaction::EIP2930Transaction
     */
    EthereumTransactionEip2930Transaction: {
        chainId: string;
        nonce: string;
        gasPrice: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
        oddYParity: string;
        r: string;
        s: string;
    };
    /**
     * Lookup188: ethereum::transaction::AccessListItem
     */
    EthereumTransactionAccessListItem: {
        address: string;
        storageKeys: string;
    };
    /**
     * Lookup189: ethereum::transaction::EIP1559Transaction
     */
    EthereumTransactionEip1559Transaction: {
        chainId: string;
        nonce: string;
        maxPriorityFeePerGas: string;
        maxFeePerGas: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
        oddYParity: string;
        r: string;
        s: string;
    };
    /**
     * Lookup190: parachain_staking::pallet::Call<T>
     */
    ParachainStakingCall: {
        _enum: {
            set_staking_expectations: {
                expectations: {
                    min: string;
                    ideal: string;
                    max: string;
                };
            };
            set_inflation: {
                schedule: {
                    min: string;
                    ideal: string;
                    max: string;
                };
            };
            set_parachain_bond_account: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_parachain_bond_reserve_percent: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_total_selected: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_collator_commission: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_blocks_per_round: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            join_candidates: {
                bond: string;
                candidateCount: string;
            };
            schedule_leave_candidates: {
                candidateCount: string;
            };
            execute_leave_candidates: {
                candidate: string;
                candidateDelegationCount: string;
            };
            cancel_leave_candidates: {
                candidateCount: string;
            };
            go_offline: string;
            go_online: string;
            candidate_bond_more: {
                more: string;
            };
            schedule_candidate_bond_less: {
                less: string;
            };
            execute_candidate_bond_less: {
                candidate: string;
            };
            cancel_candidate_bond_less: string;
            delegate: {
                candidate: string;
                amount: string;
                candidateDelegationCount: string;
                delegationCount: string;
            };
            schedule_leave_delegators: string;
            execute_leave_delegators: {
                delegator: string;
                delegationCount: string;
            };
            cancel_leave_delegators: string;
            schedule_revoke_delegation: {
                collator: string;
            };
            delegator_bond_more: {
                candidate: string;
                more: string;
            };
            schedule_delegator_bond_less: {
                candidate: string;
                less: string;
            };
            execute_delegation_request: {
                delegator: string;
                candidate: string;
            };
            cancel_delegation_request: {
                candidate: string;
            };
        };
    };
    /**
     * Lookup193: pallet_scheduler::pallet::Call<T>
     */
    PalletSchedulerCall: {
        _enum: {
            schedule: {
                when: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            cancel: {
                when: string;
                index: string;
            };
            schedule_named: {
                id: string;
                when: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            cancel_named: {
                id: string;
            };
            schedule_after: {
                after: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            schedule_named_after: {
                id: string;
                after: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
        };
    };
    /**
     * Lookup195:
     * frame_support::traits::schedule::MaybeHashed<moonbase_runtime::Call,
     * primitive_types::H256>
     */
    FrameSupportScheduleMaybeHashed: {
        _enum: {
            Value: string;
            Hash: string;
        };
    };
    /**
     * Lookup196: pallet_democracy::pallet::Call<T>
     */
    PalletDemocracyCall: {
        _enum: {
            propose: {
                proposalHash: string;
                value: string;
            };
            second: {
                proposal: string;
                secondsUpperBound: string;
            };
            vote: {
                refIndex: string;
                vote: string;
            };
            emergency_cancel: {
                refIndex: string;
            };
            external_propose: {
                proposalHash: string;
            };
            external_propose_majority: {
                proposalHash: string;
            };
            external_propose_default: {
                proposalHash: string;
            };
            fast_track: {
                proposalHash: string;
                votingPeriod: string;
                delay: string;
            };
            veto_external: {
                proposalHash: string;
            };
            cancel_referendum: {
                refIndex: string;
            };
            cancel_queued: {
                which: string;
            };
            delegate: {
                to: string;
                conviction: string;
                balance: string;
            };
            undelegate: string;
            clear_public_proposals: string;
            note_preimage: {
                encodedProposal: string;
            };
            note_preimage_operational: {
                encodedProposal: string;
            };
            note_imminent_preimage: {
                encodedProposal: string;
            };
            note_imminent_preimage_operational: {
                encodedProposal: string;
            };
            reap_preimage: {
                proposalHash: string;
                proposalLenUpperBound: string;
            };
            unlock: {
                target: string;
            };
            remove_vote: {
                index: string;
            };
            remove_other_vote: {
                target: string;
                index: string;
            };
            enact_proposal: {
                proposalHash: string;
                index: string;
            };
            blacklist: {
                proposalHash: string;
                maybeRefIndex: string;
            };
            cancel_proposal: {
                propIndex: string;
            };
        };
    };
    /**
     * Lookup197: pallet_democracy::conviction::Conviction
     */
    PalletDemocracyConviction: {
        _enum: string[];
    };
    /**
     * Lookup199: pallet_collective::pallet::Call<T, I>
     */
    PalletCollectiveCall: {
        _enum: {
            set_members: {
                newMembers: string;
                prime: string;
                oldCount: string;
            };
            execute: {
                proposal: string;
                lengthBound: string;
            };
            propose: {
                threshold: string;
                proposal: string;
                lengthBound: string;
            };
            vote: {
                proposal: string;
                index: string;
                approve: string;
            };
            close: {
                proposalHash: string;
                index: string;
                proposalWeightBound: string;
                lengthBound: string;
            };
            disapprove_proposal: {
                proposalHash: string;
            };
        };
    };
    /**
     * Lookup201: pallet_treasury::pallet::Call<T, I>
     */
    PalletTreasuryCall: {
        _enum: {
            propose_spend: {
                value: string;
                beneficiary: string;
            };
            reject_proposal: {
                proposalId: string;
            };
            approve_proposal: {
                proposalId: string;
            };
        };
    };
    /**
     * Lookup202: pallet_author_inherent::pallet::Call<T>
     */
    PalletAuthorInherentCall: {
        _enum: string[];
    };
    /**
     * Lookup203: pallet_author_slot_filter::pallet::Call<T>
     */
    PalletAuthorSlotFilterCall: {
        _enum: {
            set_eligible: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
        };
    };
    /**
     * Lookup204: pallet_crowdloan_rewards::pallet::Call<T>
     */
    PalletCrowdloanRewardsCall: {
        _enum: {
            associate_native_identity: {
                rewardAccount: string;
                relayAccount: string;
                proof: string;
            };
            change_association_with_relay_keys: {
                rewardAccount: string;
                previousAccount: string;
                proofs: string;
            };
            claim: string;
            update_reward_address: {
                newRewardAccount: string;
            };
            complete_initialization: {
                leaseEndingBlock: string;
            };
            initialize_reward_vec: {
                rewards: string;
            };
        };
    };
    /**
     * Lookup205: sp_runtime::MultiSignature
     */
    SpRuntimeMultiSignature: {
        _enum: {
            Ed25519: string;
            Sr25519: string;
            Ecdsa: string;
        };
    };
    /**
     * Lookup206: sp_core::ed25519::Signature
     */
    SpCoreEd25519Signature: string;
    /**
     * Lookup208: sp_core::sr25519::Signature
     */
    SpCoreSr25519Signature: string;
    /**
     * Lookup209: sp_core::ecdsa::Signature
     */
    SpCoreEcdsaSignature: string;
    /**
     * Lookup215: pallet_author_mapping::pallet::Call<T>
     */
    PalletAuthorMappingCall: {
        _enum: {
            add_association: {
                nimbusId: string;
            };
            update_association: {
                oldNimbusId: string;
                newNimbusId: string;
            };
            clear_association: {
                nimbusId: string;
            };
            remove_keys: string;
            set_keys: {
                _alias: {
                    keys_: string;
                };
                keys_: string;
            };
        };
    };
    /**
     * Lookup216: pallet_proxy::pallet::Call<T>
     */
    PalletProxyCall: {
        _enum: {
            proxy: {
                real: string;
                forceProxyType: string;
                call: string;
            };
            add_proxy: {
                delegate: string;
                proxyType: string;
                delay: string;
            };
            remove_proxy: {
                delegate: string;
                proxyType: string;
                delay: string;
            };
            remove_proxies: string;
            anonymous: {
                proxyType: string;
                delay: string;
                index: string;
            };
            kill_anonymous: {
                spawner: string;
                proxyType: string;
                index: string;
                height: string;
                extIndex: string;
            };
            announce: {
                real: string;
                callHash: string;
            };
            remove_announcement: {
                real: string;
                callHash: string;
            };
            reject_announcement: {
                delegate: string;
                callHash: string;
            };
            proxy_announced: {
                delegate: string;
                real: string;
                forceProxyType: string;
                call: string;
            };
        };
    };
    /**
     * Lookup218: pallet_maintenance_mode::pallet::Call<T>
     */
    PalletMaintenanceModeCall: {
        _enum: string[];
    };
    /**
     * Lookup219: pallet_identity::pallet::Call<T>
     */
    PalletIdentityCall: {
        _enum: {
            add_registrar: {
                account: string;
            };
            set_identity: {
                info: string;
            };
            set_subs: {
                subs: string;
            };
            clear_identity: string;
            request_judgement: {
                regIndex: string;
                maxFee: string;
            };
            cancel_request: {
                regIndex: string;
            };
            set_fee: {
                index: string;
                fee: string;
            };
            set_account_id: {
                _alias: {
                    new_: string;
                };
                index: string;
                new_: string;
            };
            set_fields: {
                index: string;
                fields: string;
            };
            provide_judgement: {
                regIndex: string;
                target: string;
                judgement: string;
            };
            kill_identity: {
                target: string;
            };
            add_sub: {
                sub: string;
                data: string;
            };
            rename_sub: {
                sub: string;
                data: string;
            };
            remove_sub: {
                sub: string;
            };
            quit_sub: string;
        };
    };
    /**
     * Lookup220: pallet_identity::types::IdentityInfo<FieldLimit>
     */
    PalletIdentityIdentityInfo: {
        additional: string;
        display: string;
        legal: string;
        web: string;
        riot: string;
        email: string;
        pgpFingerprint: string;
        image: string;
        twitter: string;
    };
    /**
     * Lookup256: pallet_identity::types::BitFlags<pallet_identity::types::IdentityField>
     */
    PalletIdentityBitFlags: {
        _bitLength: number;
        Display: number;
        Legal: number;
        Web: number;
        Riot: number;
        Email: number;
        PgpFingerprint: number;
        Image: number;
        Twitter: number;
    };
    /**
     * Lookup257: pallet_identity::types::IdentityField
     */
    PalletIdentityIdentityField: {
        _enum: string[];
    };
    /**
     * Lookup258: pallet_identity::types::Judgement<Balance>
     */
    PalletIdentityJudgement: {
        _enum: {
            Unknown: string;
            FeePaid: string;
            Reasonable: string;
            KnownGood: string;
            OutOfDate: string;
            LowQuality: string;
            Erroneous: string;
        };
    };
    /**
     * Lookup259: cumulus_pallet_xcmp_queue::pallet::Call<T>
     */
    CumulusPalletXcmpQueueCall: {
        _enum: {
            service_overweight: {
                index: string;
                weightLimit: string;
            };
            suspend_xcm_execution: string;
            resume_xcm_execution: string;
            update_suspend_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_drop_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_resume_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_threshold_weight: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_weight_restrict_decay: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_xcmp_max_individual_weight: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
        };
    };
    /**
     * Lookup260: cumulus_pallet_dmp_queue::pallet::Call<T>
     */
    CumulusPalletDmpQueueCall: {
        _enum: {
            service_overweight: {
                index: string;
                weightLimit: string;
            };
        };
    };
    /**
     * Lookup261: pallet_xcm::pallet::Call<T>
     */
    PalletXcmCall: {
        _enum: {
            send: {
                dest: string;
                message: string;
            };
            teleport_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
            };
            reserve_transfer_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
            };
            execute: {
                message: string;
                maxWeight: string;
            };
            force_xcm_version: {
                location: string;
                xcmVersion: string;
            };
            force_default_xcm_version: {
                maybeXcmVersion: string;
            };
            force_subscribe_version_notify: {
                location: string;
            };
            force_unsubscribe_version_notify: {
                location: string;
            };
            limited_reserve_transfer_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
                weightLimit: string;
            };
            limited_teleport_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
                weightLimit: string;
            };
        };
    };
    /**
     * Lookup262: xcm::VersionedXcm<Call>
     */
    XcmVersionedXcm: {
        _enum: {
            V0: string;
            V1: string;
            V2: string;
        };
    };
    /**
     * Lookup263: xcm::v0::Xcm<Call>
     */
    XcmV0Xcm: {
        _enum: {
            WithdrawAsset: {
                assets: string;
                effects: string;
            };
            ReserveAssetDeposit: {
                assets: string;
                effects: string;
            };
            TeleportAsset: {
                assets: string;
                effects: string;
            };
            QueryResponse: {
                queryId: string;
                response: string;
            };
            TransferAsset: {
                assets: string;
                dest: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            RelayedFrom: {
                who: string;
                message: string;
            };
        };
    };
    /**
     * Lookup265: xcm::v0::order::Order<Call>
     */
    XcmV0Order: {
        _enum: {
            Null: string;
            DepositAsset: {
                assets: string;
                dest: string;
            };
            DepositReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                effects: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                effects: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
            };
            BuyExecution: {
                fees: string;
                weight: string;
                debt: string;
                haltOnError: string;
                xcm: string;
            };
        };
    };
    /**
     * Lookup267: xcm::v0::Response
     */
    XcmV0Response: {
        _enum: {
            Assets: string;
        };
    };
    /**
     * Lookup268: xcm::v1::Xcm<Call>
     */
    XcmV1Xcm: {
        _enum: {
            WithdrawAsset: {
                assets: string;
                effects: string;
            };
            ReserveAssetDeposited: {
                assets: string;
                effects: string;
            };
            ReceiveTeleportedAsset: {
                assets: string;
                effects: string;
            };
            QueryResponse: {
                queryId: string;
                response: string;
            };
            TransferAsset: {
                assets: string;
                beneficiary: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            RelayedFrom: {
                who: string;
                message: string;
            };
            SubscribeVersion: {
                queryId: string;
                maxResponseWeight: string;
            };
            UnsubscribeVersion: string;
        };
    };
    /**
     * Lookup270: xcm::v1::order::Order<Call>
     */
    XcmV1Order: {
        _enum: {
            Noop: string;
            DepositAsset: {
                assets: string;
                maxAssets: string;
                beneficiary: string;
            };
            DepositReserveAsset: {
                assets: string;
                maxAssets: string;
                dest: string;
                effects: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                effects: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                effects: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
            };
            BuyExecution: {
                fees: string;
                weight: string;
                debt: string;
                haltOnError: string;
                instructions: string;
            };
        };
    };
    /**
     * Lookup272: xcm::v1::Response
     */
    XcmV1Response: {
        _enum: {
            Assets: string;
            Version: string;
        };
    };
    /**
     * Lookup286: pallet_assets::pallet::Call<T, I>
     */
    PalletAssetsCall: {
        _enum: {
            create: {
                id: string;
                admin: string;
                minBalance: string;
            };
            force_create: {
                id: string;
                owner: string;
                isSufficient: string;
                minBalance: string;
            };
            destroy: {
                id: string;
                witness: string;
            };
            mint: {
                id: string;
                beneficiary: string;
                amount: string;
            };
            burn: {
                id: string;
                who: string;
                amount: string;
            };
            transfer: {
                id: string;
                target: string;
                amount: string;
            };
            transfer_keep_alive: {
                id: string;
                target: string;
                amount: string;
            };
            force_transfer: {
                id: string;
                source: string;
                dest: string;
                amount: string;
            };
            freeze: {
                id: string;
                who: string;
            };
            thaw: {
                id: string;
                who: string;
            };
            freeze_asset: {
                id: string;
            };
            thaw_asset: {
                id: string;
            };
            transfer_ownership: {
                id: string;
                owner: string;
            };
            set_team: {
                id: string;
                issuer: string;
                admin: string;
                freezer: string;
            };
            set_metadata: {
                id: string;
                name: string;
                symbol: string;
                decimals: string;
            };
            clear_metadata: {
                id: string;
            };
            force_set_metadata: {
                id: string;
                name: string;
                symbol: string;
                decimals: string;
                isFrozen: string;
            };
            force_clear_metadata: {
                id: string;
            };
            force_asset_status: {
                id: string;
                owner: string;
                issuer: string;
                admin: string;
                freezer: string;
                minBalance: string;
                isSufficient: string;
                isFrozen: string;
            };
            approve_transfer: {
                id: string;
                delegate: string;
                amount: string;
            };
            cancel_approval: {
                id: string;
                delegate: string;
            };
            force_cancel_approval: {
                id: string;
                owner: string;
                delegate: string;
            };
            transfer_approved: {
                id: string;
                owner: string;
                destination: string;
                amount: string;
            };
            touch: {
                id: string;
            };
            refund: {
                id: string;
                allowBurn: string;
            };
        };
    };
    /**
     * Lookup287: pallet_assets::types::DestroyWitness
     */
    PalletAssetsDestroyWitness: {
        accounts: string;
        sufficients: string;
        approvals: string;
    };
    /**
     * Lookup288: orml_xtokens::module::Call<T>
     */
    OrmlXtokensModuleCall: {
        _enum: {
            transfer: {
                currencyId: string;
                amount: string;
                dest: string;
                destWeight: string;
            };
            transfer_multiasset: {
                asset: string;
                dest: string;
                destWeight: string;
            };
            transfer_with_fee: {
                currencyId: string;
                amount: string;
                fee: string;
                dest: string;
                destWeight: string;
            };
            transfer_multiasset_with_fee: {
                asset: string;
                fee: string;
                dest: string;
                destWeight: string;
            };
            transfer_multicurrencies: {
                currencies: string;
                feeItem: string;
                dest: string;
                destWeight: string;
            };
            transfer_multiassets: {
                assets: string;
                feeItem: string;
                dest: string;
                destWeight: string;
            };
        };
    };
    /**
     * Lookup289: moonbase_runtime::xcm_config::CurrencyId
     */
    MoonbaseRuntimeXcmConfigCurrencyId: {
        _enum: {
            SelfReserve: string;
            ForeignAsset: string;
            LocalAssetReserve: string;
        };
    };
    /**
     * Lookup290: xcm::VersionedMultiAsset
     */
    XcmVersionedMultiAsset: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup293: pallet_asset_manager::pallet::Call<T>
     */
    PalletAssetManagerCall: {
        _enum: {
            register_foreign_asset: {
                asset: string;
                metadata: string;
                minAmount: string;
                isSufficient: string;
            };
            set_asset_units_per_second: {
                assetType: string;
                unitsPerSecond: string;
                numAssetsWeightHint: string;
            };
            change_existing_asset_type: {
                assetId: string;
                newAssetType: string;
                numAssetsWeightHint: string;
            };
            remove_supported_asset: {
                assetType: string;
                numAssetsWeightHint: string;
            };
            remove_existing_asset_type: {
                assetId: string;
                numAssetsWeightHint: string;
            };
            register_local_asset: {
                creator: string;
                owner: string;
                isSufficient: string;
                minBalance: string;
            };
            destroy_foreign_asset: {
                assetId: string;
                destroyAssetWitness: string;
                numAssetsWeightHint: string;
            };
            destroy_local_asset: {
                assetId: string;
                destroyAssetWitness: string;
            };
        };
    };
    /**
     * Lookup294: xcm_transactor::pallet::Call<T>
     */
    XcmTransactorCall: {
        _enum: {
            register: {
                who: string;
                index: string;
            };
            deregister: {
                index: string;
            };
            transact_through_derivative_multilocation: {
                dest: string;
                index: string;
                feeLocation: string;
                destWeight: string;
                innerCall: string;
            };
            transact_through_derivative: {
                dest: string;
                index: string;
                currencyId: string;
                destWeight: string;
                innerCall: string;
            };
            transact_through_sovereign: {
                dest: string;
                feePayer: string;
                feeLocation: string;
                destWeight: string;
                call: string;
                originKind: string;
            };
            set_transact_info: {
                location: string;
                transactExtraWeight: string;
                maxWeight: string;
                transactExtraWeightSigned: string;
            };
            remove_transact_info: {
                location: string;
            };
            transact_through_signed: {
                dest: string;
                feeCurrencyId: string;
                destWeight: string;
                call: string;
            };
            transact_through_signed_multilocation: {
                dest: string;
                feeLocation: string;
                destWeight: string;
                call: string;
            };
            set_fee_per_second: {
                assetLocation: string;
                feePerSecond: string;
            };
            remove_fee_per_second: {
                assetLocation: string;
            };
        };
    };
    /**
     * Lookup295: moonbase_runtime::xcm_config::Transactors
     */
    MoonbaseRuntimeXcmConfigTransactors: {
        _enum: string[];
    };
    /**
     * Lookup296: pallet_base_fee::pallet::Call<T>
     */
    PalletBaseFeeCall: {
        _enum: {
            set_base_fee_per_gas: {
                fee: string;
            };
            set_is_active: {
                isActive: string;
            };
            set_elasticity: {
                elasticity: string;
            };
        };
    };
    /**
     * Lookup298: pallet_moonbeam_orbiters::pallet::Call<T>
     */
    PalletMoonbeamOrbitersCall: {
        _enum: {
            collator_add_orbiter: {
                orbiter: string;
            };
            collator_remove_orbiter: {
                orbiter: string;
            };
            orbiter_leave_collator_pool: {
                collator: string;
            };
            orbiter_register: string;
            orbiter_unregister: {
                collatorsPoolCount: string;
            };
            add_collator: {
                collator: string;
            };
            remove_collator: {
                collator: string;
            };
        };
    };
    /**
     * Lookup299: moonbase_runtime::OriginCaller
     */
    MoonbaseRuntimeOriginCaller: {
        _enum: {
            system: string;
            __Unused1: string;
            __Unused2: string;
            __Unused3: string;
            __Unused4: string;
            __Unused5: string;
            Void: string;
            __Unused7: string;
            __Unused8: string;
            __Unused9: string;
            __Unused10: string;
            Ethereum: string;
            __Unused12: string;
            __Unused13: string;
            __Unused14: string;
            CouncilCollective: string;
            TechCommitteeCollective: string;
            __Unused17: string;
            __Unused18: string;
            __Unused19: string;
            __Unused20: string;
            __Unused21: string;
            __Unused22: string;
            __Unused23: string;
            __Unused24: string;
            __Unused25: string;
            CumulusXcm: string;
            __Unused27: string;
            PolkadotXcm: string;
        };
    };
    /**
     * Lookup300:
     * frame_support::dispatch::RawOrigin[account::AccountId20](account::AccountId20)
     */
    FrameSupportDispatchRawOrigin: {
        _enum: {
            Root: string;
            Signed: string;
            None: string;
        };
    };
    /**
     * Lookup301: pallet_ethereum::RawOrigin
     */
    PalletEthereumRawOrigin: {
        _enum: {
            EthereumTransaction: string;
        };
    };
    /**
     * Lookup302: pallet_collective::RawOrigin<account::AccountId20, I>
     */
    PalletCollectiveRawOrigin: {
        _enum: {
            Members: string;
            Member: string;
            _Phantom: string;
        };
    };
    /**
     * Lookup304: cumulus_pallet_xcm::pallet::Origin
     */
    CumulusPalletXcmOrigin: {
        _enum: {
            Relay: string;
            SiblingParachain: string;
        };
    };
    /**
     * Lookup305: pallet_xcm::pallet::Origin
     */
    PalletXcmOrigin: {
        _enum: {
            Xcm: string;
            Response: string;
        };
    };
    /**
     * Lookup306: sp_core::Void
     */
    SpCoreVoid: string;
    /**
     * Lookup307: pallet_utility::pallet::Error<T>
     */
    PalletUtilityError: {
        _enum: string[];
    };
    /**
     * Lookup309: pallet_balances::BalanceLock<Balance>
     */
    PalletBalancesBalanceLock: {
        id: string;
        amount: string;
        reasons: string;
    };
    /**
     * Lookup310: pallet_balances::Reasons
     */
    PalletBalancesReasons: {
        _enum: string[];
    };
    /**
     * Lookup313: pallet_balances::ReserveData<ReserveIdentifier, Balance>
     */
    PalletBalancesReserveData: {
        id: string;
        amount: string;
    };
    /**
     * Lookup315: pallet_balances::Releases
     */
    PalletBalancesReleases: {
        _enum: string[];
    };
    /**
     * Lookup316: pallet_balances::pallet::Error<T, I>
     */
    PalletBalancesError: {
        _enum: string[];
    };
    /**
     * Lookup317: pallet_sudo::pallet::Error<T>
     */
    PalletSudoError: {
        _enum: string[];
    };
    /**
     * Lookup320: polkadot_primitives::v2::UpgradeRestriction
     */
    PolkadotPrimitivesV2UpgradeRestriction: {
        _enum: string[];
    };
    /**
     * Lookup321:
     * cumulus_pallet_parachain_system::relay_state_snapshot::MessagingStateSnapshot
     */
    CumulusPalletParachainSystemRelayStateSnapshotMessagingStateSnapshot: {
        dmqMqcHead: string;
        relayDispatchQueueSize: string;
        ingressChannels: string;
        egressChannels: string;
    };
    /**
     * Lookup324: polkadot_primitives::v2::AbridgedHrmpChannel
     */
    PolkadotPrimitivesV2AbridgedHrmpChannel: {
        maxCapacity: string;
        maxTotalSize: string;
        maxMessageSize: string;
        msgCount: string;
        totalSize: string;
        mqcHead: string;
    };
    /**
     * Lookup325: polkadot_primitives::v2::AbridgedHostConfiguration
     */
    PolkadotPrimitivesV2AbridgedHostConfiguration: {
        maxCodeSize: string;
        maxHeadDataSize: string;
        maxUpwardQueueCount: string;
        maxUpwardQueueSize: string;
        maxUpwardMessageSize: string;
        maxUpwardMessageNumPerCandidate: string;
        hrmpMaxMessageNumPerCandidate: string;
        validationUpgradeCooldown: string;
        validationUpgradeDelay: string;
    };
    /**
     * Lookup331:
     * polkadot_core_primitives::OutboundHrmpMessage<polkadot_parachain::primitives::Id>
     */
    PolkadotCorePrimitivesOutboundHrmpMessage: {
        recipient: string;
        data: string;
    };
    /**
     * Lookup332: cumulus_pallet_parachain_system::pallet::Error<T>
     */
    CumulusPalletParachainSystemError: {
        _enum: string[];
    };
    /**
     * Lookup334: pallet_transaction_payment::Releases
     */
    PalletTransactionPaymentReleases: {
        _enum: string[];
    };
    /**
     * Lookup336: frame_support::weights::WeightToFeeCoefficient<Balance>
     */
    FrameSupportWeightsWeightToFeeCoefficient: {
        coeffInteger: string;
        coeffFrac: string;
        negative: string;
        degree: string;
    };
    /**
     * Lookup338: pallet_evm::pallet::Error<T>
     */
    PalletEvmError: {
        _enum: string[];
    };
    /**
     * Lookup341: fp_rpc::TransactionStatus
     */
    FpRpcTransactionStatus: {
        transactionHash: string;
        transactionIndex: string;
        from: string;
        to: string;
        contractAddress: string;
        logs: string;
        logsBloom: string;
    };
    /**
     * Lookup344: ethbloom::Bloom
     */
    EthbloomBloom: string;
    /**
     * Lookup346: ethereum::receipt::ReceiptV3
     */
    EthereumReceiptReceiptV3: {
        _enum: {
            Legacy: string;
            EIP2930: string;
            EIP1559: string;
        };
    };
    /**
     * Lookup347: ethereum::receipt::EIP658ReceiptData
     */
    EthereumReceiptEip658ReceiptData: {
        statusCode: string;
        usedGas: string;
        logsBloom: string;
        logs: string;
    };
    /**
     * Lookup348:
     * ethereum::block::Block[ethereum::transaction::TransactionV2](ethereum::transaction::TransactionV2)
     */
    EthereumBlock: {
        header: string;
        transactions: string;
        ommers: string;
    };
    /**
     * Lookup349: ethereum::header::Header
     */
    EthereumHeader: {
        parentHash: string;
        ommersHash: string;
        beneficiary: string;
        stateRoot: string;
        transactionsRoot: string;
        receiptsRoot: string;
        logsBloom: string;
        difficulty: string;
        number: string;
        gasLimit: string;
        gasUsed: string;
        timestamp: string;
        extraData: string;
        mixHash: string;
        nonce: string;
    };
    /**
     * Lookup350: ethereum_types::hash::H64
     */
    EthereumTypesHashH64: string;
    /**
     * Lookup355: pallet_ethereum::pallet::Error<T>
     */
    PalletEthereumError: {
        _enum: string[];
    };
    /**
     * Lookup356:
     * parachain_staking::types::ParachainBondConfig[account::AccountId20](account::AccountId20)
     */
    ParachainStakingParachainBondConfig: {
        account: string;
        percent: string;
    };
    /**
     * Lookup357: parachain_staking::types::RoundInfo<BlockNumber>
     */
    ParachainStakingRoundInfo: {
        current: string;
        first: string;
        length: string;
    };
    /**
     * Lookup358: parachain_staking::types::Nominator2<account::AccountId20, Balance>
     */
    ParachainStakingNominator2: {
        delegations: string;
        revocations: string;
        total: string;
        scheduledRevocationsCount: string;
        scheduledRevocationsTotal: string;
        status: string;
    };
    /**
     * Lookup359:
     * parachain_staking::set::OrderedSet<parachain_staking::types::Bond<account::AccountId20,
     * Balance>>
     */
    ParachainStakingSetOrderedSetBond: string;
    /**
     * Lookup360: parachain_staking::types::Bond<account::AccountId20, Balance>
     */
    ParachainStakingBond: {
        owner: string;
        amount: string;
    };
    /**
     * Lookup362:
     * parachain_staking::set::OrderedSet[account::AccountId20](account::AccountId20)
     */
    ParachainStakingSetOrderedSetAccountId20: string;
    /**
     * Lookup363: parachain_staking::types::DelegatorStatus
     */
    ParachainStakingDelegatorStatus: {
        _enum: {
            Active: string;
            Leaving: string;
        };
    };
    /**
     * Lookup364: parachain_staking::types::Delegator<account::AccountId20, Balance>
     */
    ParachainStakingDelegator: {
        id: string;
        delegations: string;
        total: string;
        lessTotal: string;
        status: string;
    };
    /**
     * Lookup365: parachain_staking::types::CollatorCandidate<account::AccountId20, Balance>
     */
    ParachainStakingCollatorCandidate: {
        id: string;
        bond: string;
        delegators: string;
        topDelegations: string;
        bottomDelegations: string;
        totalCounted: string;
        totalBacking: string;
        request: string;
        state: string;
    };
    /**
     * Lookup367: parachain_staking::types::CandidateBondLessRequest<Balance>
     */
    ParachainStakingCandidateBondLessRequest: {
        amount: string;
        whenExecutable: string;
    };
    /**
     * Lookup368: parachain_staking::types::CollatorStatus
     */
    ParachainStakingCollatorStatus: {
        _enum: {
            Active: string;
            Idle: string;
            Leaving: string;
        };
    };
    /**
     * Lookup369: parachain_staking::types::CandidateMetadata<Balance>
     */
    ParachainStakingCandidateMetadata: {
        bond: string;
        delegationCount: string;
        totalCounted: string;
        lowestTopDelegationAmount: string;
        highestBottomDelegationAmount: string;
        lowestBottomDelegationAmount: string;
        topCapacity: string;
        bottomCapacity: string;
        request: string;
        status: string;
    };
    /**
     * Lookup370: parachain_staking::types::CapacityStatus
     */
    ParachainStakingCapacityStatus: {
        _enum: string[];
    };
    /**
     * Lookup372:
     * parachain_staking::delegation_requests::ScheduledRequest<account::AccountId20,
     * Balance>
     */
    ParachainStakingDelegationRequestsScheduledRequest: {
        delegator: string;
        whenExecutable: string;
        action: string;
    };
    /**
     * Lookup373: parachain_staking::types::Delegations<account::AccountId20, Balance>
     */
    ParachainStakingDelegations: {
        delegations: string;
        total: string;
    };
    /**
     * Lookup374: parachain_staking::types::Collator2<account::AccountId20, Balance>
     */
    ParachainStakingCollator2: {
        id: string;
        bond: string;
        nominators: string;
        topNominators: string;
        bottomNominators: string;
        totalCounted: string;
        totalBacking: string;
        state: string;
    };
    /**
     * Lookup376: parachain_staking::types::CollatorSnapshot<account::AccountId20, Balance>
     */
    ParachainStakingCollatorSnapshot: {
        bond: string;
        delegations: string;
        total: string;
    };
    /**
     * Lookup377: parachain_staking::types::DelayedPayout<Balance>
     */
    ParachainStakingDelayedPayout: {
        roundIssuance: string;
        totalStakingReward: string;
        collatorCommission: string;
    };
    /**
     * Lookup378: parachain_staking::inflation::InflationInfo<Balance>
     */
    ParachainStakingInflationInflationInfo: {
        expect: {
            min: string;
            ideal: string;
            max: string;
        };
        annual: {
            min: string;
            ideal: string;
            max: string;
        };
        round: {
            min: string;
            ideal: string;
            max: string;
        };
    };
    /**
     * Lookup379: parachain_staking::pallet::Error<T>
     */
    ParachainStakingError: {
        _enum: string[];
    };
    /**
     * Lookup382:
     * pallet_scheduler::ScheduledV3<frame_support::traits::schedule::MaybeHashed<moonbase_runtime::Call,
     * primitive_types::H256>, BlockNumber, moonbase_runtime::OriginCaller,
     * account::AccountId20>
     */
    PalletSchedulerScheduledV3: {
        maybeId: string;
        priority: string;
        call: string;
        maybePeriodic: string;
        origin: string;
    };
    /**
     * Lookup383: pallet_scheduler::pallet::Error<T>
     */
    PalletSchedulerError: {
        _enum: string[];
    };
    /**
     * Lookup387: pallet_democracy::PreimageStatus<account::AccountId20, Balance,
     * BlockNumber>
     */
    PalletDemocracyPreimageStatus: {
        _enum: {
            Missing: string;
            Available: {
                data: string;
                provider: string;
                deposit: string;
                since: string;
                expiry: string;
            };
        };
    };
    /**
     * Lookup388: pallet_democracy::types::ReferendumInfo<BlockNumber,
     * primitive_types::H256, Balance>
     */
    PalletDemocracyReferendumInfo: {
        _enum: {
            Ongoing: string;
            Finished: {
                approved: string;
                end: string;
            };
        };
    };
    /**
     * Lookup389: pallet_democracy::types::ReferendumStatus<BlockNumber,
     * primitive_types::H256, Balance>
     */
    PalletDemocracyReferendumStatus: {
        end: string;
        proposalHash: string;
        threshold: string;
        delay: string;
        tally: string;
    };
    /**
     * Lookup390: pallet_democracy::types::Tally<Balance>
     */
    PalletDemocracyTally: {
        ayes: string;
        nays: string;
        turnout: string;
    };
    /**
     * Lookup391: pallet_democracy::vote::Voting<Balance, account::AccountId20, BlockNumber>
     */
    PalletDemocracyVoteVoting: {
        _enum: {
            Direct: {
                votes: string;
                delegations: string;
                prior: string;
            };
            Delegating: {
                balance: string;
                target: string;
                conviction: string;
                delegations: string;
                prior: string;
            };
        };
    };
    /**
     * Lookup394: pallet_democracy::types::Delegations<Balance>
     */
    PalletDemocracyDelegations: {
        votes: string;
        capital: string;
    };
    /**
     * Lookup395: pallet_democracy::vote::PriorLock<BlockNumber, Balance>
     */
    PalletDemocracyVotePriorLock: string;
    /**
     * Lookup398: pallet_democracy::Releases
     */
    PalletDemocracyReleases: {
        _enum: string[];
    };
    /**
     * Lookup399: pallet_democracy::pallet::Error<T>
     */
    PalletDemocracyError: {
        _enum: string[];
    };
    /**
     * Lookup401: pallet_collective::Votes<account::AccountId20, BlockNumber>
     */
    PalletCollectiveVotes: {
        index: string;
        threshold: string;
        ayes: string;
        nays: string;
        end: string;
    };
    /**
     * Lookup402: pallet_collective::pallet::Error<T, I>
     */
    PalletCollectiveError: {
        _enum: string[];
    };
    /**
     * Lookup404: pallet_treasury::Proposal<account::AccountId20, Balance>
     */
    PalletTreasuryProposal: {
        proposer: string;
        value: string;
        beneficiary: string;
        bond: string;
    };
    /**
     * Lookup408: frame_support::PalletId
     */
    FrameSupportPalletId: string;
    /**
     * Lookup409: pallet_treasury::pallet::Error<T, I>
     */
    PalletTreasuryError: {
        _enum: string[];
    };
    /**
     * Lookup410: pallet_author_inherent::pallet::Error<T>
     */
    PalletAuthorInherentError: {
        _enum: string[];
    };
    /**
     * Lookup411: pallet_crowdloan_rewards::pallet::RewardInfo<T>
     */
    PalletCrowdloanRewardsRewardInfo: {
        totalReward: string;
        claimedReward: string;
        contributedRelayAddresses: string;
    };
    /**
     * Lookup413: pallet_crowdloan_rewards::pallet::Error<T>
     */
    PalletCrowdloanRewardsError: {
        _enum: string[];
    };
    /**
     * Lookup414: pallet_author_mapping::pallet::RegistrationInfo<T>
     */
    PalletAuthorMappingRegistrationInfo: {
        _alias: {
            keys_: string;
        };
        account: string;
        deposit: string;
        keys_: string;
    };
    /**
     * Lookup415: pallet_author_mapping::pallet::Error<T>
     */
    PalletAuthorMappingError: {
        _enum: string[];
    };
    /**
     * Lookup418: pallet_proxy::ProxyDefinition<account::AccountId20,
     * moonbase_runtime::ProxyType, BlockNumber>
     */
    PalletProxyProxyDefinition: {
        delegate: string;
        proxyType: string;
        delay: string;
    };
    /**
     * Lookup422: pallet_proxy::Announcement<account::AccountId20,
     * primitive_types::H256, BlockNumber>
     */
    PalletProxyAnnouncement: {
        real: string;
        callHash: string;
        height: string;
    };
    /**
     * Lookup424: pallet_proxy::pallet::Error<T>
     */
    PalletProxyError: {
        _enum: string[];
    };
    /**
     * Lookup425: pallet_maintenance_mode::pallet::Error<T>
     */
    PalletMaintenanceModeError: {
        _enum: string[];
    };
    /**
     * Lookup426: pallet_identity::types::Registration<Balance, MaxJudgements,
     * MaxAdditionalFields>
     */
    PalletIdentityRegistration: {
        judgements: string;
        deposit: string;
        info: string;
    };
    /**
     * Lookup434: pallet_identity::types::RegistrarInfo<Balance, account::AccountId20>
     */
    PalletIdentityRegistrarInfo: {
        account: string;
        fee: string;
        fields: string;
    };
    /**
     * Lookup436: pallet_identity::pallet::Error<T>
     */
    PalletIdentityError: {
        _enum: string[];
    };
    /**
     * Lookup438: cumulus_pallet_xcmp_queue::InboundChannelDetails
     */
    CumulusPalletXcmpQueueInboundChannelDetails: {
        sender: string;
        state: string;
        messageMetadata: string;
    };
    /**
     * Lookup439: cumulus_pallet_xcmp_queue::InboundState
     */
    CumulusPalletXcmpQueueInboundState: {
        _enum: string[];
    };
    /**
     * Lookup442: polkadot_parachain::primitives::XcmpMessageFormat
     */
    PolkadotParachainPrimitivesXcmpMessageFormat: {
        _enum: string[];
    };
    /**
     * Lookup445: cumulus_pallet_xcmp_queue::OutboundChannelDetails
     */
    CumulusPalletXcmpQueueOutboundChannelDetails: {
        recipient: string;
        state: string;
        signalsExist: string;
        firstIndex: string;
        lastIndex: string;
    };
    /**
     * Lookup446: cumulus_pallet_xcmp_queue::OutboundState
     */
    CumulusPalletXcmpQueueOutboundState: {
        _enum: string[];
    };
    /**
     * Lookup448: cumulus_pallet_xcmp_queue::QueueConfigData
     */
    CumulusPalletXcmpQueueQueueConfigData: {
        suspendThreshold: string;
        dropThreshold: string;
        resumeThreshold: string;
        thresholdWeight: string;
        weightRestrictDecay: string;
        xcmpMaxIndividualWeight: string;
    };
    /**
     * Lookup450: cumulus_pallet_xcmp_queue::pallet::Error<T>
     */
    CumulusPalletXcmpQueueError: {
        _enum: string[];
    };
    /**
     * Lookup451: cumulus_pallet_xcm::pallet::Error<T>
     */
    CumulusPalletXcmError: string;
    /**
     * Lookup452: cumulus_pallet_dmp_queue::ConfigData
     */
    CumulusPalletDmpQueueConfigData: {
        maxIndividual: string;
    };
    /**
     * Lookup453: cumulus_pallet_dmp_queue::PageIndexData
     */
    CumulusPalletDmpQueuePageIndexData: {
        beginUsed: string;
        endUsed: string;
        overweightCount: string;
    };
    /**
     * Lookup456: cumulus_pallet_dmp_queue::pallet::Error<T>
     */
    CumulusPalletDmpQueueError: {
        _enum: string[];
    };
    /**
     * Lookup457: pallet_xcm::pallet::QueryStatus<BlockNumber>
     */
    PalletXcmQueryStatus: {
        _enum: {
            Pending: {
                responder: string;
                maybeNotify: string;
                timeout: string;
            };
            VersionNotifier: {
                origin: string;
                isActive: string;
            };
            Ready: {
                response: string;
                at: string;
            };
        };
    };
    /**
     * Lookup460: xcm::VersionedResponse
     */
    XcmVersionedResponse: {
        _enum: {
            V0: string;
            V1: string;
            V2: string;
        };
    };
    /**
     * Lookup466: pallet_xcm::pallet::VersionMigrationStage
     */
    PalletXcmVersionMigrationStage: {
        _enum: {
            MigrateSupportedVersion: string;
            MigrateVersionNotifiers: string;
            NotifyCurrentTargets: string;
            MigrateAndNotifyOldTargets: string;
        };
    };
    /**
     * Lookup467: pallet_xcm::pallet::Error<T>
     */
    PalletXcmError: {
        _enum: string[];
    };
    /**
     * Lookup468: pallet_assets::types::AssetDetails<Balance,
     * account::AccountId20, DepositBalance>
     */
    PalletAssetsAssetDetails: {
        owner: string;
        issuer: string;
        admin: string;
        freezer: string;
        supply: string;
        deposit: string;
        minBalance: string;
        isSufficient: string;
        accounts: string;
        sufficients: string;
        approvals: string;
        isFrozen: string;
    };
    /**
     * Lookup470: pallet_assets::types::AssetAccount<Balance, DepositBalance, Extra>
     */
    PalletAssetsAssetAccount: {
        balance: string;
        isFrozen: string;
        reason: string;
        extra: string;
    };
    /**
     * Lookup471: pallet_assets::types::ExistenceReason<Balance>
     */
    PalletAssetsExistenceReason: {
        _enum: {
            Consumer: string;
            Sufficient: string;
            DepositHeld: string;
            DepositRefunded: string;
        };
    };
    /**
     * Lookup473: pallet_assets::types::Approval<Balance, DepositBalance>
     */
    PalletAssetsApproval: {
        amount: string;
        deposit: string;
    };
    /**
     * Lookup474: pallet_assets::types::AssetMetadata<DepositBalance,
     * frame_support::storage::bounded_vec::BoundedVec<T, S>>
     */
    PalletAssetsAssetMetadata: {
        deposit: string;
        name: string;
        symbol: string;
        decimals: string;
        isFrozen: string;
    };
    /**
     * Lookup476: pallet_assets::pallet::Error<T, I>
     */
    PalletAssetsError: {
        _enum: string[];
    };
    /**
     * Lookup477: orml_xtokens::module::Error<T>
     */
    OrmlXtokensModuleError: {
        _enum: string[];
    };
    /**
     * Lookup478: pallet_asset_manager::pallet::AssetInfo<T>
     */
    PalletAssetManagerAssetInfo: {
        creator: string;
        deposit: string;
    };
    /**
     * Lookup480: pallet_asset_manager::pallet::Error<T>
     */
    PalletAssetManagerError: {
        _enum: string[];
    };
    /**
     * Lookup481: xcm_transactor::pallet::Error<T>
     */
    XcmTransactorError: {
        _enum: string[];
    };
    /**
     * Lookup483:
     * pallet_moonbeam_orbiters::types::CollatorPoolInfo[account::AccountId20](account::AccountId20)
     */
    PalletMoonbeamOrbitersCollatorPoolInfo: {
        orbiters: string;
        maybeCurrentOrbiter: string;
        nextOrbiter: string;
    };
    /**
     * Lookup485:
     * pallet_moonbeam_orbiters::types::CurrentOrbiter[account::AccountId20](account::AccountId20)
     */
    PalletMoonbeamOrbitersCurrentOrbiter: {
        accountId: string;
        removed: string;
    };
    /**
     * Lookup486: pallet_moonbeam_orbiters::pallet::Error<T>
     */
    PalletMoonbeamOrbitersError: {
        _enum: string[];
    };
    /**
     * Lookup488: account::EthereumSignature
     */
    AccountEthereumSignature: string;
    /**
     * Lookup490: frame_system::extensions::check_spec_version::CheckSpecVersion<T>
     */
    FrameSystemExtensionsCheckSpecVersion: string;
    /**
     * Lookup491: frame_system::extensions::check_tx_version::CheckTxVersion<T>
     */
    FrameSystemExtensionsCheckTxVersion: string;
    /**
     * Lookup492: frame_system::extensions::check_genesis::CheckGenesis<T>
     */
    FrameSystemExtensionsCheckGenesis: string;
    /**
     * Lookup495: frame_system::extensions::check_nonce::CheckNonce<T>
     */
    FrameSystemExtensionsCheckNonce: string;
    /**
     * Lookup496: frame_system::extensions::check_weight::CheckWeight<T>
     */
    FrameSystemExtensionsCheckWeight: string;
    /**
     * Lookup497: pallet_transaction_payment::ChargeTransactionPayment<T>
     */
    PalletTransactionPaymentChargeTransactionPayment: string;
    /**
     * Lookup499: moonbase_runtime::Runtime
     */
    MoonbaseRuntimeRuntime: string;
};
export default _default;
